Index: src/builtins.cc |
diff --git a/src/builtins.cc b/src/builtins.cc |
index d0c1a446a8beb9e80e5ddce6fab385d74468363c..d03f48228bb457a5818258c1183f516e08764e37 100644 |
--- a/src/builtins.cc |
+++ b/src/builtins.cc |
@@ -1068,7 +1068,7 @@ BUILTIN(ArrayConcat) { |
// ----------------------------------------------------------------------------- |
// Strict mode poison pills |
BUILTIN(StrictModePoisonPill) { |
@@ -1078,6 +1078,13 @@ BUILTIN(StrictModePoisonPill) { |
} |
+BUILTIN(GeneratorPoisonPill) { |
+ HandleScope scope(isolate); |
+ return isolate->Throw(*isolate->factory()->NewTypeError( |
+ "generator_poison_pill", HandleVector<Object>(NULL, 0))); |
+} |
+ |
+ |
// ----------------------------------------------------------------------------- |
// |
@@ -1068,7 +1068,7 @@ BUILTIN(ArrayConcat) { |
// ----------------------------------------------------------------------------- |
-// Strict mode poison pills |
+// Generator and strict mode poison pills |
BUILTIN(StrictModePoisonPill) { |